<?php
/**
 * @file class_erConfig.inc
 * Class that handles the configuration
 * @author Roland Hieber (roland.hieber@wilhelm-gym.net)
 * @date 21.10.2007
 *
 * Copyright © 2007 Roland Hieber
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

require_once("sec/secure.inc");
require_once("mod_error-reporter/functions.inc");
require_once("db.inc");

/** @todo document */
class erConfig {

  /**
   * Determine if a privilege has been assigned
   * @param $sPriv (string) Privilege to test
   * @return bool
   */
  public static function privilegeAssigned($sPriv) {
    $h = db_query("SELECT act FROM privileges_assign WHERE privilege = $1;",
    $sPriv);
    return pg_num_rows($h) > 0;
  }

  /**
   * Retrieve all groups that have a privilege assigned
   * @param $strPriv (string) Privilege to test
   * @return array
   */
  public static function privilegedGroups($strPriv) {
    $aReturn = array();
    $h = db_query("SELECT act FROM privileges_assign WHERE privilege = $1 ".
    "ORDER BY act;", $strPriv);
    if(pg_num_rows($h) > 0) {
      while($a = pg_fetch_array($h)) {
        $aReturn[] = $a["act"];
      }
    }
    return $aReturn;
  }

  /**
   * Determine if the current user is allowed to see and report errors. This
   * function tests if the user is member of a group which has the
   * <tt>mod-errorreporter_access</tt> privilege.
   * @return bool
   */
  public static function userHasAccess() {
    if(erConfig::userIsAdmin() ||
    !erConfig::privilegeAssigned("mod_errorreporter_access")) {
      // user is admin or privilege is not assigned
      return true;
    } else {
      return secure_privilege("mod_errorreporter_access");
    }
  }

  /**
   * Determine if the current user has admin rights. This function tests if
   * the user is member of a group which has the
   * <tt>mod-errorreporter_access</tt> privilege
   * @return bool
   */
  public static function userIsAdmin() {
    return secure_privilege("mod_errorreporter_admin");
  }

  /** @} */
}
?>
