#!/usr/bin/php
<?php
/**
 * @file update.php
 * Perform the update operations like renaming SQL tables
 * @author Roland Hieber (roland.hieber@wilhelm-gym.net)
 * @date 23.10.2007
 * 
 * Copyright © 2007 Roland Hieber
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *  
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

/* this file is run by iservchk */
require_once("/usr/share/iserv/www/inc/quote.inc");
require_once("/usr/share/iserv/www/inc/db.inc");

function table_exists($table) {
  return pg_num_rows(db_query("SELECT * FROM information_schema.tables WHERE ".
    "table_catalog = 'iserv' AND table_name = ".qdb($table).";")) > 0;
}
function column_exists($table, $column) {
  return table_exists($table) && pg_num_rows(db_query("SELECT * FROM ".
    "information_schema.columns WHERE table_name = ".qdb($table)." AND ".
    "column_name = ".qdb($column).";")) > 0;
}
function print_sql($cmd) { 
  echo $cmd."\n";
  db_query($cmd);
}

if(isset($_SERVER["REMOTE_ADDR"])) {
  die("Run this script as root from the command line.");
}

/*** database schema updates **************************************************/
echo "updating database schema... \n";

/** table from pre-3.0 **/
if(table_exists("errors") and !column_exists("errors", "pclabel")) {
  print_sql("ALTER TABLE errors RENAME COLUMN pc_number TO pclabel;");
}

/** table from 3.0 **/
if(table_exists("errors") and !column_exists("errors", "pclabel")) {
  print_sql("INSERT INTO mod_errorreporter (er_date,er_act,er_machine,er_text,".
    "er_comment,er_commentact,er_hidden) SELECT date,name,pclabel,text,".
    "comment,commentby,hidden FROM errors;");
  print_sql("DROP TABLE errors;");
}

/** table from 4.0 **/
if(table_exists("errorreports")) {
  print_sql("INSERT INTO mod_errorreporter (er_date,er_act,er_machine,er_text,".
    "er_comment,er_commentact,er_hidden) SELECT er_date,er_act,er_machine,".
    "er_text,er_comment,er_commentact,er_hidden FROM errorreports;"); 
  print_sql("DROP TABLE errorreports;");
}

echo "done.\n";
?>
